@@ -62,7 +62,7 @@ static void ClearPropagatedData(OMX_BUFFERHEADERTYPE* header)
   header->pMarkData = nullptr;
   header->nFilledLen = 0;
   header->nTickCount = 0;
-  header->nFlags = 0;
+  header->nFlags = header->nFlags & OMX_BUFFERFLAG_DATACORRUPT ? OMX_BUFFERFLAG_DATACORRUPT : 0;
 }
 
 void Component::ReturnEmptiedBuffer(OMX_BUFFERHEADERTYPE* emptied)
@@ -574,7 +574,6 @@ OMX_ERRORTYPE Component::GetParameter(OMX_IN OMX_INDEXTYPE index, OMX_INOUT OMX_
     auto subframe = static_cast<OMX_ALG_VIDEO_PARAM_SUBFRAME*>(param);
     return ConstructVideoSubframe(*subframe, *port, media);
   }
-  // only encoder
   case OMX_IndexParamVideoQuantization:
   {
     auto port = getCurrentPort(param);
@@ -725,13 +724,24 @@ OMX_ERRORTYPE Component::GetParameter(OMX_IN OMX_INDEXTYPE index, OMX_INOUT OMX_
     auto mps = static_cast<OMX_ALG_VIDEO_PARAM_MAX_PICTURE_SIZE*>(param);
     return ConstructVideoMaxPictureSize(*mps, *port, media);
   }
+  case OMX_ALG_IndexParamVideoMaxPictureSizeInBits:
+  {
+    auto port = getCurrentPort(param);
+    auto mps = static_cast<OMX_ALG_VIDEO_PARAM_MAX_PICTURE_SIZE_IN_BITS*>(param);
+    return ConstructVideoMaxPictureSizeInBits(*mps, *port, media);
+  }
   case OMX_ALG_IndexParamVideoMaxPictureSizes:
   {
     auto port = getCurrentPort(param);
     auto mps = static_cast<OMX_ALG_VIDEO_PARAM_MAX_PICTURE_SIZES*>(param);
     return ConstructVideoMaxPictureSizes(*mps, *port, media);
   }
-  // only decoder
+  case OMX_ALG_IndexParamVideoMaxPictureSizesInBits:
+  {
+    auto port = getCurrentPort(param);
+    auto mps = static_cast<OMX_ALG_VIDEO_PARAM_MAX_PICTURE_SIZES_IN_BITS*>(param);
+    return ConstructVideoMaxPictureSizesInBits(*mps, *port, media);
+  }
   case OMX_ALG_IndexParamPreallocation:
   {
     auto prealloc = static_cast<OMX_ALG_PARAM_PREALLOCATION*>(param);
@@ -820,6 +830,12 @@ OMX_ERRORTYPE Component::GetParameter(OMX_IN OMX_INDEXTYPE index, OMX_INOUT OMX_
     auto cllSEI = static_cast<OMX_ALG_VIDEO_PARAM_CONTENT_LIGHT_LEVEL_SEI*>(param);
     return ConstructVideoContentLightLevelSEI(*cllSEI, *port, media);
   }
+  case OMX_ALG_IndexParamVideoAlternativeTransferCharacteristicsSEI:
+  {
+    auto port = getCurrentPort(param);
+    auto atcSEI = static_cast<OMX_ALG_VIDEO_PARAM_ALTERNATIVE_TRANSFER_CHARACTERISTICS_SEI*>(param);
+    return ConstructVideoAlternativeTransferCharacteristicsSEI(*atcSEI, *port, media);
+  }
   case OMX_ALG_IndexParamVideoST209410SEI:
   {
     auto port = getCurrentPort(param);
@@ -844,11 +860,23 @@ OMX_ERRORTYPE Component::GetParameter(OMX_IN OMX_INDEXTYPE index, OMX_INOUT OMX_
     auto crop = static_cast<OMX_CONFIG_RECTTYPE*>(param);
     return ConstructVideoCrop(*crop, *port, media);
   }
-  case OMX_ALG_IndexParamVideoMaxPictureSizesInBits:
+  case OMX_ALG_IndexParamVideoUniformSliceType:
   {
     auto port = getCurrentPort(param);
-    auto mps = static_cast<OMX_ALG_VIDEO_PARAM_MAX_PICTURE_SIZES_IN_BITS*>(param);
-    return ConstructVideoMaxPictureSizesInBits(*mps, *port, media);
+    auto ust = static_cast<OMX_ALG_VIDEO_PARAM_UNIFORM_SLICE_TYPE*>(param);
+    return ConstructVideoUniformSliceType(*ust, *port, media);
+  }
+  case OMX_ALG_IndexParamVideoOutputPosition:
+  {
+    auto port = getCurrentPort(param);
+    auto position = static_cast<OMX_CONFIG_POINTTYPE*>(param);
+    return ConstructVideoOutputPosition(*position, *port, media);
+  }
+  case OMX_ALG_IndexParamVideoStartCodeBytesAlignment:
+  {
+    auto port = getCurrentPort(param);
+    auto scba = static_cast<OMX_ALG_VIDEO_PARAM_START_CODE_BYTES_ALIGNMENT*>(param);
+    return ConstructVideoStartCodeBytesAlignment(*scba, *port, media);
   }
   default:
     LOG_ERROR(ToStringOMXIndex(index) + string { " is unsupported" });
@@ -939,7 +967,6 @@ OMX_ERRORTYPE Component::SetParameter(OMX_IN OMX_INDEXTYPE index, OMX_IN OMX_PTR
     auto portBufferMode = static_cast<OMX_ALG_PORT_PARAM_BUFFER_MODE*>(param);
     return SetPortBufferMode(*portBufferMode, *port, media);
   }
-  // only encoder
   case OMX_IndexParamVideoQuantization:
   {
     auto quantization = static_cast<OMX_VIDEO_PARAM_QUANTIZATIONTYPE*>(param);
@@ -1060,11 +1087,22 @@ OMX_ERRORTYPE Component::SetParameter(OMX_IN OMX_INDEXTYPE index, OMX_IN OMX_PTR
     auto mps = static_cast<OMX_ALG_VIDEO_PARAM_MAX_PICTURE_SIZE*>(param);
     return SetVideoMaxPictureSize(*mps, *port, media);
   }
+  case OMX_ALG_IndexParamVideoMaxPictureSizeInBits:
+  {
+    auto mps = static_cast<OMX_ALG_VIDEO_PARAM_MAX_PICTURE_SIZE_IN_BITS*>(param);
+    return SetVideoMaxPictureSizeInBits(*mps, *port, media);
+  }
+
   case OMX_ALG_IndexParamVideoMaxPictureSizes:
   {
     auto mps = static_cast<OMX_ALG_VIDEO_PARAM_MAX_PICTURE_SIZES*>(param);
     return SetVideoMaxPictureSizes(*mps, *port, media);
   }
+  case OMX_ALG_IndexParamVideoMaxPictureSizesInBits:
+  {
+    auto mps = static_cast<OMX_ALG_VIDEO_PARAM_MAX_PICTURE_SIZES_IN_BITS*>(param);
+    return SetVideoMaxPictureSizesInBits(*mps, *port, media);
+  }
   case OMX_ALG_IndexParamVideoLoopFilterBeta:
   {
     auto lfb = static_cast<OMX_ALG_VIDEO_PARAM_LOOP_FILTER_BETA*>(param);
@@ -1075,7 +1113,6 @@ OMX_ERRORTYPE Component::SetParameter(OMX_IN OMX_INDEXTYPE index, OMX_IN OMX_PTR
     auto lftc = static_cast<OMX_ALG_VIDEO_PARAM_LOOP_FILTER_TC*>(param);
     return SetVideoLoopFilterTc(*lftc, *port, media);
   }
-  // only decoder
   case OMX_ALG_IndexParamPreallocation:
   {
     auto p = (OMX_ALG_PARAM_PREALLOCATION*)param;
@@ -1138,6 +1175,11 @@ OMX_ERRORTYPE Component::SetParameter(OMX_IN OMX_INDEXTYPE index, OMX_IN OMX_PTR
     auto cllSEI = static_cast<OMX_ALG_VIDEO_PARAM_CONTENT_LIGHT_LEVEL_SEI*>(param);
     return SetVideoContentLightLevelSEI(*cllSEI, *port, media);
   }
+  case OMX_ALG_IndexParamVideoAlternativeTransferCharacteristicsSEI:
+  {
+    auto atcSEI = static_cast<OMX_ALG_VIDEO_PARAM_ALTERNATIVE_TRANSFER_CHARACTERISTICS_SEI*>(param);
+    return SetVideoAlternativeTransferCharacteristicsSEI(*atcSEI, *port, media);
+  }
   case OMX_ALG_IndexParamVideoST209410SEI:
   {
     auto st209410 = static_cast<OMX_ALG_VIDEO_PARAM_ST2094_10_SEI*>(param);
@@ -1158,10 +1200,20 @@ OMX_ERRORTYPE Component::SetParameter(OMX_IN OMX_INDEXTYPE index, OMX_IN OMX_PTR
     auto crop = static_cast<OMX_CONFIG_RECTTYPE*>(param);
     return SetVideoCrop(*crop, *port, media);
   }
-  case OMX_ALG_IndexParamVideoMaxPictureSizesInBits:
+  case OMX_ALG_IndexParamVideoUniformSliceType:
   {
-    auto mps = static_cast<OMX_ALG_VIDEO_PARAM_MAX_PICTURE_SIZES_IN_BITS*>(param);
-    return SetVideoMaxPictureSizesInBits(*mps, *port, media);
+    auto ust = static_cast<OMX_ALG_VIDEO_PARAM_UNIFORM_SLICE_TYPE*>(param);
+    return SetVideoUniformSliceType(*ust, *port, media);
+  }
+  case OMX_ALG_IndexParamVideoOutputPosition:
+  {
+    auto position = static_cast<OMX_CONFIG_POINTTYPE*>(param);
+    return SetVideoOutputPosition(*position, *port, media);
+  }
+  case OMX_ALG_IndexParamVideoStartCodeBytesAlignment:
+  {
+    auto scba = static_cast<OMX_ALG_VIDEO_PARAM_START_CODE_BYTES_ALIGNMENT*>(param);
+    return SetVideoStartCodeBytesAlignment(*scba, *port, media);
   }
   default:
     LOG_ERROR(ToStringOMXIndex(index) + string { " is unsupported" });
