@@ -1319,6 +1319,46 @@ OMX_ERRORTYPE SetVideoMaxPictureSizes(OMX_ALG_VIDEO_PARAM_MAX_PICTURE_SIZES cons
   return OMX_ErrorNone;
 }
 
+OMX_ERRORTYPE ConstructVideoMaxPictureSizesInBits(OMX_ALG_VIDEO_PARAM_MAX_PICTURE_SIZES_IN_BITS& maxPictureSize, Port const& port, std::shared_ptr<MediatypeInterface> media)
+{
+  OMXChecker::SetHeaderVersion(maxPictureSize);
+  maxPictureSize.nPortIndex = port.index;
+  MaxPicturesSizes mps;
+  auto ret = media->Get(SETTINGS_INDEX_MAX_PICTURE_SIZES_IN_BITS, &mps);
+  OMX_CHECK_MEDIA_GET(ret);
+  maxPictureSize.nMaxPictureSizeI = mps.i;
+  maxPictureSize.nMaxPictureSizeP = mps.p;
+  maxPictureSize.nMaxPictureSizeB = mps.b;
+  return OMX_ErrorNone;
+}
+
+static OMX_ERRORTYPE SetMaxPictureSizesInBits(OMX_S32 mpsI, OMX_S32 mpsP, OMX_S32 mpsB, shared_ptr<MediatypeInterface> media)
+{
+  MaxPicturesSizes mps;
+  mps.i = static_cast<int>(mpsI);
+  mps.p = static_cast<int>(mpsP);
+  mps.b = static_cast<int>(mpsB);
+  auto ret = media->Set(SETTINGS_INDEX_MAX_PICTURE_SIZES_IN_BITS, &mps);
+  OMX_CHECK_MEDIA_SET(ret);
+  return OMX_ErrorNone;
+}
+
+OMX_ERRORTYPE SetVideoMaxPictureSizesInBits(OMX_ALG_VIDEO_PARAM_MAX_PICTURE_SIZES_IN_BITS const& maxPictureSize, Port const& port, std::shared_ptr<MediatypeInterface> media)
+{
+  OMX_ALG_VIDEO_PARAM_MAX_PICTURE_SIZES_IN_BITS rollback;
+  ConstructVideoMaxPictureSizesInBits(rollback, port, media);
+
+  auto ret = SetMaxPictureSizesInBits(maxPictureSize.nMaxPictureSizeI, maxPictureSize.nMaxPictureSizeP, maxPictureSize.nMaxPictureSizeB, media);
+
+  if(ret != OMX_ErrorNone)
+  {
+    SetVideoMaxPictureSizesInBits(rollback, port, media);
+    throw ret;
+  }
+
+  return OMX_ErrorNone;
+}
+
 OMX_ERRORTYPE ConstructVideoMaxPictureSize(OMX_ALG_VIDEO_PARAM_MAX_PICTURE_SIZE& maxPictureSize, Port const& port, std::shared_ptr<MediatypeInterface> media)
 {
   OMXChecker::SetHeaderVersion(maxPictureSize);
@@ -1346,6 +1386,33 @@ OMX_ERRORTYPE SetVideoMaxPictureSize(OMX_ALG_VIDEO_PARAM_MAX_PICTURE_SIZE const&
   return OMX_ErrorNone;
 }
 
+OMX_ERRORTYPE ConstructVideoMaxPictureSizeInBits(OMX_ALG_VIDEO_PARAM_MAX_PICTURE_SIZE_IN_BITS& maxPictureSize, Port const& port, std::shared_ptr<MediatypeInterface> media)
+{
+  OMXChecker::SetHeaderVersion(maxPictureSize);
+  maxPictureSize.nPortIndex = port.index;
+  MaxPicturesSizes mps;
+  auto ret = media->Get(SETTINGS_INDEX_MAX_PICTURE_SIZES_IN_BITS, &mps);
+  OMX_CHECK_MEDIA_GET(ret);
+  maxPictureSize.nMaxPictureSize = max(max(mps.i, mps.p), mps.b);
+  return OMX_ErrorNone;
+}
+
+OMX_ERRORTYPE SetVideoMaxPictureSizeInBits(OMX_ALG_VIDEO_PARAM_MAX_PICTURE_SIZE_IN_BITS const& maxPictureSize, Port const& port, std::shared_ptr<MediatypeInterface> media)
+{
+  OMX_ALG_VIDEO_PARAM_MAX_PICTURE_SIZES rollback;
+  ConstructVideoMaxPictureSizesInBits(rollback, port, media);
+
+  auto ret = SetMaxPictureSizesInBits(maxPictureSize.nMaxPictureSize, maxPictureSize.nMaxPictureSize, maxPictureSize.nMaxPictureSize, media);
+
+  if(ret != OMX_ErrorNone)
+  {
+    SetVideoMaxPictureSizesInBits(rollback, port, media);
+    throw ret;
+  }
+
+  return OMX_ErrorNone;
+}
+
 OMX_ERRORTYPE ConstructVideoLoopFilterBeta(OMX_ALG_VIDEO_PARAM_LOOP_FILTER_BETA& loopFilterBeta, Port const& port, std::shared_ptr<MediatypeInterface> media)
 {
   OMXChecker::SetHeaderVersion(loopFilterBeta);
@@ -1859,6 +1926,42 @@ OMX_ERRORTYPE SetVideoContentLightLevelSEI(OMX_ALG_VIDEO_PARAM_CONTENT_LIGHT_LEV
   return OMX_ErrorNone;
 }
 
+OMX_ERRORTYPE ConstructVideoAlternativeTransferCharacteristicsSEI(OMX_ALG_VIDEO_PARAM_ALTERNATIVE_TRANSFER_CHARACTERISTICS_SEI& atcSEI, Port const& port, std::shared_ptr<MediatypeInterface> media)
+{
+  OMXChecker::SetHeaderVersion(atcSEI);
+  atcSEI.nPortIndex = port.index;
+  bool isATCEnabled {
+    false
+  };
+  auto ret = media->Get(SETTINGS_INDEX_ALTERNATIVE_TRANSFER_CHARACTERISTICS_SEI, &isATCEnabled);
+  OMX_CHECK_MEDIA_GET(ret);
+  atcSEI.bEnableAlternativeTransferCharacteristicsSEI = ConvertMediaToOMXBool(isATCEnabled);
+  return OMX_ErrorNone;
+}
+
+static OMX_ERRORTYPE SetAlternativeTransferCharacteristicsSEI(OMX_BOOL bEnableAlternativeTransferCharacteristicsSEI, shared_ptr<MediatypeInterface> media)
+{
+  auto isATCEnabled = ConvertOMXToMediaBool(bEnableAlternativeTransferCharacteristicsSEI);
+  auto ret = media->Set(SETTINGS_INDEX_ALTERNATIVE_TRANSFER_CHARACTERISTICS_SEI, &isATCEnabled);
+  OMX_CHECK_MEDIA_SET(ret);
+  return OMX_ErrorNone;
+}
+
+OMX_ERRORTYPE SetVideoAlternativeTransferCharacteristicsSEI(OMX_ALG_VIDEO_PARAM_ALTERNATIVE_TRANSFER_CHARACTERISTICS_SEI const& atcSEI, Port const& port, std::shared_ptr<MediatypeInterface> media)
+{
+  OMX_ALG_VIDEO_PARAM_ALTERNATIVE_TRANSFER_CHARACTERISTICS_SEI rollback;
+  ConstructVideoAlternativeTransferCharacteristicsSEI(rollback, port, media);
+  auto ret = SetAlternativeTransferCharacteristicsSEI(atcSEI.bEnableAlternativeTransferCharacteristicsSEI, media);
+
+  if(ret != OMX_ErrorNone)
+  {
+    SetVideoAlternativeTransferCharacteristicsSEI(rollback, port, media);
+    throw ret;
+  }
+
+  return OMX_ErrorNone;
+}
+
 OMX_ERRORTYPE ConstructVideoST209410SEI(OMX_ALG_VIDEO_PARAM_ST2094_10_SEI& st2094_10SEI, Port const& port, std::shared_ptr<MediatypeInterface> media)
 {
   OMXChecker::SetHeaderVersion(st2094_10SEI);
@@ -1954,14 +2057,15 @@ OMX_ERRORTYPE ConstructVideoRateControlPlugin(OMX_ALG_VIDEO_PARAM_RATE_CONTROL_P
   return OMX_ErrorNone;
 }
 
-static OMX_ERRORTYPE SetCrop(OMX_U32 nLeft, OMX_U32 nTop, OMX_U32 nWidth, OMX_U32 nHeight, shared_ptr<MediatypeInterface> media)
+static OMX_ERRORTYPE SetCrop(OMX_U32 portIndex, OMX_U32 nLeft, OMX_U32 nTop, OMX_U32 nWidth, OMX_U32 nHeight, shared_ptr<MediatypeInterface> media)
 {
   Region region;
   region.point.x = nLeft;
   region.point.y = nTop;
   region.dimension.horizontal = nWidth;
   region.dimension.vertical = nHeight;
-  auto ret = media->Set(SETTINGS_INDEX_CROP, &region);
+  auto indexSettings = IsInputPort(portIndex) ? SETTINGS_INDEX_INPUT_CROP : SETTINGS_INDEX_OUTPUT_CROP;
+  auto ret = media->Set(indexSettings, &region);
   OMX_CHECK_MEDIA_SET(ret);
   return OMX_ErrorNone;
 }
@@ -1970,7 +2074,7 @@ OMX_ERRORTYPE SetVideoCrop(OMX_CONFIG_RECTTYPE const& crop, Port const& port, st
 {
   OMX_CONFIG_RECTTYPE rollback;
   ConstructVideoCrop(rollback, port, media);
-  auto ret = SetCrop(crop.nLeft, crop.nTop, crop.nWidth, crop.nHeight, media);
+  auto ret = SetCrop(port.index, crop.nLeft, crop.nTop, crop.nWidth, crop.nHeight, media);
 
   if(ret != OMX_ErrorNone)
   {
@@ -1986,7 +2090,9 @@ OMX_ERRORTYPE ConstructVideoCrop(OMX_CONFIG_RECTTYPE& crop, Port const& port, st
   OMXChecker::SetHeaderVersion(crop);
   crop.nPortIndex = port.index;
   Region region {};
-  auto ret = media->Get(SETTINGS_INDEX_CROP, &region);
+
+  auto index = IsInputPort(port.index) ? SETTINGS_INDEX_INPUT_CROP : SETTINGS_INDEX_OUTPUT_CROP;
+  auto ret = media->Get(index, &region);
   OMX_CHECK_MEDIA_GET(ret);
   crop.nLeft = region.point.x;
   crop.nTop = region.point.y;
@@ -1995,42 +2101,114 @@ OMX_ERRORTYPE ConstructVideoCrop(OMX_CONFIG_RECTTYPE& crop, Port const& port, st
   return OMX_ErrorNone;
 }
 
-OMX_ERRORTYPE ConstructVideoMaxPictureSizesInBits(OMX_ALG_VIDEO_PARAM_MAX_PICTURE_SIZES_IN_BITS& maxPictureSize, Port const& port, std::shared_ptr<MediatypeInterface> media)
+static OMX_ERRORTYPE SetUniformSliceType(OMX_BOOL bEnableUniformSliceType, shared_ptr<MediatypeInterface> media)
 {
-  OMXChecker::SetHeaderVersion(maxPictureSize);
-  maxPictureSize.nPortIndex = port.index;
-  MaxPicturesSizes mps;
-  auto ret = media->Get(SETTINGS_INDEX_MAX_PICTURE_SIZES_IN_BITS, &mps);
-  OMX_CHECK_MEDIA_GET(ret);
-  maxPictureSize.nMaxPictureSizeI = mps.i;
-  maxPictureSize.nMaxPictureSizeP = mps.p;
-  maxPictureSize.nMaxPictureSizeB = mps.b;
-  return OMX_ErrorNone;
-}
-
-static OMX_ERRORTYPE SetMaxPictureSizesInBits(OMX_S32 mpsI, OMX_S32 mpsP, OMX_S32 mpsB, shared_ptr<MediatypeInterface> media)
-{
-  MaxPicturesSizes mps;
-  mps.i = static_cast<int>(mpsI);
-  mps.p = static_cast<int>(mpsP);
-  mps.b = static_cast<int>(mpsB);
-  auto ret = media->Set(SETTINGS_INDEX_MAX_PICTURE_SIZES_IN_BITS, &mps);
+  auto isUniformSliceTypeEnabled = ConvertOMXToMediaBool(bEnableUniformSliceType);
+  auto ret = media->Set(SETTINGS_INDEX_UNIFORM_SLICE_TYPE, &isUniformSliceTypeEnabled);
   OMX_CHECK_MEDIA_SET(ret);
   return OMX_ErrorNone;
 }
 
-OMX_ERRORTYPE SetVideoMaxPictureSizesInBits(OMX_ALG_VIDEO_PARAM_MAX_PICTURE_SIZES_IN_BITS const& maxPictureSize, Port const& port, std::shared_ptr<MediatypeInterface> media)
+OMX_ERRORTYPE SetVideoUniformSliceType(OMX_ALG_VIDEO_PARAM_UNIFORM_SLICE_TYPE const& ust, Port const& port, std::shared_ptr<MediatypeInterface> media)
 {
-  OMX_ALG_VIDEO_PARAM_MAX_PICTURE_SIZES_IN_BITS rollback;
-  ConstructVideoMaxPictureSizesInBits(rollback, port, media);
-
-  auto ret = SetMaxPictureSizesInBits(maxPictureSize.nMaxPictureSizeI, maxPictureSize.nMaxPictureSizeP, maxPictureSize.nMaxPictureSizeB, media);
+  OMX_ALG_VIDEO_PARAM_UNIFORM_SLICE_TYPE rollback;
+  ConstructVideoUniformSliceType(rollback, port, media);
+  auto ret = SetUniformSliceType(ust.bEnableUniformSliceType, media);
 
   if(ret != OMX_ErrorNone)
   {
-    SetVideoMaxPictureSizesInBits(rollback, port, media);
+    SetVideoUniformSliceType(rollback, port, media);
     throw ret;
   }
 
   return OMX_ErrorNone;
 }
+
+OMX_ERRORTYPE ConstructVideoUniformSliceType(OMX_ALG_VIDEO_PARAM_UNIFORM_SLICE_TYPE& ust, Port const& port, std::shared_ptr<MediatypeInterface> media)
+{
+  OMXChecker::SetHeaderVersion(ust);
+  ust.nPortIndex = port.index;
+  bool bIsUniformSliceTypeEnabled {
+    false
+  };
+  auto ret = media->Get(SETTINGS_INDEX_UNIFORM_SLICE_TYPE, &bIsUniformSliceTypeEnabled);
+  OMX_CHECK_MEDIA_GET(ret);
+  return OMX_ErrorNone;
+}
+
+static OMX_ERRORTYPE SetOutputPosition(OMX_S32 nX, OMX_S32 nY, shared_ptr<MediatypeInterface> media)
+{
+  Point<int> point {};
+  point.x = nX;
+  point.y = nY;
+  auto ret = media->Set(SETTINGS_INDEX_OUTPUT_POSITION, &point);
+  OMX_CHECK_MEDIA_SET(ret);
+  return OMX_ErrorNone;
+}
+
+OMX_ERRORTYPE SetVideoOutputPosition(OMX_CONFIG_POINTTYPE const& position, Port const& port, std::shared_ptr<MediatypeInterface> media)
+{
+  if(IsInputPort(port.index))
+    throw OMX_ErrorBadParameter;
+
+  OMX_CONFIG_POINTTYPE rollback;
+  ConstructVideoOutputPosition(rollback, port, media);
+  auto ret = SetOutputPosition(position.nX, position.nY, media);
+
+  if(ret != OMX_ErrorNone)
+  {
+    SetVideoOutputPosition(rollback, port, media);
+    throw ret;
+  }
+
+  return OMX_ErrorNone;
+}
+
+OMX_ERRORTYPE ConstructVideoOutputPosition(OMX_CONFIG_POINTTYPE& position, Port const& port, std::shared_ptr<MediatypeInterface> media)
+{
+  if(IsInputPort(port.index))
+    throw OMX_ErrorBadParameter;
+
+  OMXChecker::SetHeaderVersion(position);
+  position.nPortIndex = port.index;
+  Point<int> point {};
+  auto ret = media->Get(SETTINGS_INDEX_OUTPUT_POSITION, &point);
+  OMX_CHECK_MEDIA_GET(ret);
+  position.nX = point.x;
+  position.nY = point.y;
+  return OMX_ErrorNone;
+}
+
+static OMX_ERRORTYPE SetStartCodeBytesAlignmet(OMX_ALG_EStartCodeBytesAligment eStartCodeBytesAlignment, shared_ptr<MediatypeInterface> media)
+{
+  auto startCodeBytesAlignment = ConvertOMXToMediaStartCodeBytesAlignment(eStartCodeBytesAlignment);
+  auto ret = media->Set(SETTINGS_INDEX_START_CODE_BYTES_ALIGNMENT, &startCodeBytesAlignment);
+  OMX_CHECK_MEDIA_SET(ret);
+  return OMX_ErrorNone;
+}
+
+OMX_ERRORTYPE SetVideoStartCodeBytesAlignment(OMX_ALG_VIDEO_PARAM_START_CODE_BYTES_ALIGNMENT const& scba, Port const& port, std::shared_ptr<MediatypeInterface> media)
+{
+  OMX_ALG_VIDEO_PARAM_START_CODE_BYTES_ALIGNMENT rollback;
+  ConstructVideoStartCodeBytesAlignment(rollback, port, media);
+  auto ret = SetStartCodeBytesAlignmet(scba.eStartCodeBytesAlignment, media);
+
+  if(ret != OMX_ErrorNone)
+  {
+    SetVideoStartCodeBytesAlignment(rollback, port, media);
+    throw ret;
+  }
+
+  return OMX_ErrorNone;
+}
+
+OMX_ERRORTYPE ConstructVideoStartCodeBytesAlignment(OMX_ALG_VIDEO_PARAM_START_CODE_BYTES_ALIGNMENT& scba, Port const& port, std::shared_ptr<MediatypeInterface> media)
+{
+  OMXChecker::SetHeaderVersion(scba);
+  scba.nPortIndex = port.index;
+  StartCodeBytesAlignmentType startCodeBytesAligment;
+  auto ret = media->Get(SETTINGS_INDEX_START_CODE_BYTES_ALIGNMENT, &startCodeBytesAligment);
+  OMX_CHECK_MEDIA_GET(ret);
+  scba.eStartCodeBytesAlignment = ConvertMediaToOMXStartCodeBytesAlignment(startCodeBytesAligment);
+  return OMX_ErrorNone;
+}
