@@ -1159,8 +1159,22 @@ OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS ConvertMediaToOMXTransferCharacteristics(
 {
   switch(transferCharac)
   {
+  case TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_BT_709: return OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_BT_709;
   case TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_UNSPECIFIED: return OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_UNSPECIFIED;
+  case TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_BT_470_SYSTEM_M: return OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_BT_470_SYSTEM_M;
+  case TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_BT_470_SYSTEM_B: return OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_BT_470_SYSTEM_B;
+  case TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_BT_601: return OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_BT_601;
+  case TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_SMPTE_240M: return OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_SMPTE_240M;
+  case TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_LINEAR: return OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_LINEAR;
+  case TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_LOG: return OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_LOG;
+  case TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_LOG_EXTENDED: return OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_LOG_EXTENDED;
+  case TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_IEC_61966_2_4: return OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_IEC_61966_2_4;
+  case TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_BT_1361: return OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_BT_1361;
+  case TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_IEC_61966_2_1: return OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_IEC_61966_2_1;
+  case TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_BT_2020_10B: return OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_BT_2020_10B;
+  case TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_BT_2020_12B: return OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_BT_2020_12B;
   case TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_BT_2100_PQ: return OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_BT_2100_PQ;
+  case TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_SMPTE_428: return OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_SMPTE_428;
   case TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_BT_2100_HLG: return OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_BT_2100_HLG;
   default: return OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_MAX_ENUM;
   }
@@ -1172,8 +1186,22 @@ TransferCharacteristicsType ConvertOMXToMediaTransferCharacteristics(OMX_ALG_VID
 {
   switch(transferCharac)
   {
+  case OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_BT_709: return TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_BT_709;
   case OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_UNSPECIFIED: return TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_UNSPECIFIED;
+  case OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_BT_470_SYSTEM_M: return TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_BT_470_SYSTEM_M;
+  case OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_BT_470_SYSTEM_B: return TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_BT_470_SYSTEM_B;
+  case OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_BT_601: return TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_BT_601;
+  case OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_SMPTE_240M: return TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_SMPTE_240M;
+  case OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_LINEAR: return TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_LINEAR;
+  case OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_LOG: return TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_LOG;
+  case OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_LOG_EXTENDED: return TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_LOG_EXTENDED;
+  case OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_IEC_61966_2_4: return TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_IEC_61966_2_4;
+  case OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_BT_1361: return TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_BT_1361;
+  case OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_IEC_61966_2_1: return TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_IEC_61966_2_1;
+  case OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_BT_2020_10B: return TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_BT_2020_10B;
+  case OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_BT_2020_12B: return TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_BT_2020_12B;
   case OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_BT_2100_PQ: return TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_BT_2100_PQ;
+  case OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_SMPTE_428: return TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_SMPTE_428;
   case OMX_ALG_VIDEO_TRANSFER_CHARACTERISTICS_BT_2100_HLG: return TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_BT_2100_HLG;
   default: return TransferCharacteristicsType::TRANSFER_CHARACTERISTICS_MAX_ENUM;
   }
@@ -1185,8 +1213,20 @@ OMX_ALG_VIDEO_COLOR_MATRIX ConvertMediaToOMXColourMatrix(ColourMatrixType colour
 {
   switch(colourMatrix)
   {
+  case ColourMatrixType::COLOUR_MATRIX_GBR: return OMX_ALG_VIDEO_COLOR_MATRIX_GBR;
+  case ColourMatrixType::COLOUR_MATRIX_BT_709: return OMX_ALG_VIDEO_COLOR_MATRIX_BT_709;
   case ColourMatrixType::COLOUR_MATRIX_UNSPECIFIED: return OMX_ALG_VIDEO_COLOR_MATRIX_UNSPECIFIED;
+  case ColourMatrixType::COLOUR_MATRIX_USFCC_CFR: return OMX_ALG_VIDEO_COLOR_MATRIX_USFCC_CFR;
+  case ColourMatrixType::COLOUR_MATRIX_BT_601_625: return OMX_ALG_VIDEO_COLOR_MATRIX_BT_601_625;
+  case ColourMatrixType::COLOUR_MATRIX_BT_601_525: return OMX_ALG_VIDEO_COLOR_MATRIX_BT_601_525;
+  case ColourMatrixType::COLOUR_MATRIX_BT_SMPTE_240M: return OMX_ALG_VIDEO_COLOR_MATRIX_BT_SMPTE_240M;
+  case ColourMatrixType::COLOUR_MATRIX_BT_YCGCO: return OMX_ALG_VIDEO_COLOR_MATRIX_BT_YCGCO;
   case ColourMatrixType::COLOUR_MATRIX_BT_2100_YCBCR: return OMX_ALG_VIDEO_COLOR_MATRIX_BT_2100_YCBCR;
+  case ColourMatrixType::COLOUR_MATRIX_BT_2020_CLS: return OMX_ALG_VIDEO_COLOR_MATRIX_BT_2020_CLS;
+  case ColourMatrixType::COLOUR_MATRIX_SMPTE_2085: return OMX_ALG_VIDEO_COLOR_MATRIX_SMPTE_2085;
+  case ColourMatrixType::COLOUR_MATRIX_CHROMA_DERIVED_NCLS: return OMX_ALG_VIDEO_COLOR_MATRIX_CHROMA_DERIVED_NCLS;
+  case ColourMatrixType::COLOUR_MATRIX_CHROMA_DERIVED_CLS: return OMX_ALG_VIDEO_COLOR_MATRIX_CHROMA_DERIVED_CLS;
+  case ColourMatrixType::COLOUR_MATRIX_BT_2100_ICTCP: return OMX_ALG_VIDEO_COLOR_MATRIX_BT_2100_ICTCP;
   default: return OMX_ALG_VIDEO_COLOR_MATRIX_MAX_ENUM;
   }
 
@@ -1197,8 +1237,20 @@ ColourMatrixType ConvertOMXToMediaColourMatrix(OMX_ALG_VIDEO_COLOR_MATRIX colour
 {
   switch(colourMatrix)
   {
+  case OMX_ALG_VIDEO_COLOR_MATRIX_GBR: return ColourMatrixType::COLOUR_MATRIX_GBR;
+  case OMX_ALG_VIDEO_COLOR_MATRIX_BT_709: return ColourMatrixType::COLOUR_MATRIX_BT_709;
   case OMX_ALG_VIDEO_COLOR_MATRIX_UNSPECIFIED: return ColourMatrixType::COLOUR_MATRIX_UNSPECIFIED;
+  case OMX_ALG_VIDEO_COLOR_MATRIX_USFCC_CFR: return ColourMatrixType::COLOUR_MATRIX_USFCC_CFR;
+  case OMX_ALG_VIDEO_COLOR_MATRIX_BT_601_625: return ColourMatrixType::COLOUR_MATRIX_BT_601_625;
+  case OMX_ALG_VIDEO_COLOR_MATRIX_BT_601_525: return ColourMatrixType::COLOUR_MATRIX_BT_601_525;
+  case OMX_ALG_VIDEO_COLOR_MATRIX_BT_SMPTE_240M: return ColourMatrixType::COLOUR_MATRIX_BT_SMPTE_240M;
+  case OMX_ALG_VIDEO_COLOR_MATRIX_BT_YCGCO: return ColourMatrixType::COLOUR_MATRIX_BT_YCGCO;
   case OMX_ALG_VIDEO_COLOR_MATRIX_BT_2100_YCBCR: return ColourMatrixType::COLOUR_MATRIX_BT_2100_YCBCR;
+  case OMX_ALG_VIDEO_COLOR_MATRIX_BT_2020_CLS: return ColourMatrixType::COLOUR_MATRIX_BT_2020_CLS;
+  case OMX_ALG_VIDEO_COLOR_MATRIX_SMPTE_2085: return ColourMatrixType::COLOUR_MATRIX_SMPTE_2085;
+  case OMX_ALG_VIDEO_COLOR_MATRIX_CHROMA_DERIVED_NCLS: return ColourMatrixType::COLOUR_MATRIX_CHROMA_DERIVED_NCLS;
+  case OMX_ALG_VIDEO_COLOR_MATRIX_CHROMA_DERIVED_CLS: return ColourMatrixType::COLOUR_MATRIX_CHROMA_DERIVED_CLS;
+  case OMX_ALG_VIDEO_COLOR_MATRIX_BT_2100_ICTCP: return ColourMatrixType::COLOUR_MATRIX_BT_2100_ICTCP;
   default: return ColourMatrixType::COLOUR_MATRIX_MAX_ENUM;
   }
 
@@ -1248,6 +1300,14 @@ OMX_ALG_VIDEO_CONFIG_HIGH_DYNAMIC_RANGE_SEI ConvertMediaToOMXHDRSEI(HighDynamicR
     omxHDRSEIs.contentLightLevel.nMaxPicAverageLightLevel = hdrSEIs.contentLightLevel.maxPicAverageLightLevel;
   }
 
+  omxHDRSEIs.bHasATC = ConvertMediaToOMXBool(hdrSEIs.hasATC);
+
+  if(omxHDRSEIs.bHasATC)
+  {
+    omxHDRSEIs.alternativeTransferCharacteristics.preferredTransferCharacteristics =
+      ConvertMediaToOMXTransferCharacteristics(hdrSEIs.alternativeTransferCharacteristics.preferredTransferCharacteristics);
+  }
+
   omxHDRSEIs.bHasST2094_10 = ConvertMediaToOMXBool(hdrSEIs.hasST2094_10);
 
   if(hdrSEIs.hasST2094_10)
@@ -1397,6 +1457,14 @@ HighDynamicRangeSeis ConvertOMXToMediaHDRSEI(OMX_ALG_VIDEO_CONFIG_HIGH_DYNAMIC_R
     modHDRSEIs.contentLightLevel.maxPicAverageLightLevel = hdrSEIs.contentLightLevel.nMaxPicAverageLightLevel;
   }
 
+  modHDRSEIs.hasATC = ConvertOMXToMediaBool(hdrSEIs.bHasATC);
+
+  if(modHDRSEIs.hasATC)
+  {
+    modHDRSEIs.alternativeTransferCharacteristics.preferredTransferCharacteristics =
+      ConvertOMXToMediaTransferCharacteristics(hdrSEIs.alternativeTransferCharacteristics.preferredTransferCharacteristics);
+  }
+
   modHDRSEIs.hasST2094_10 = ConvertOMXToMediaBool(hdrSEIs.bHasST2094_10);
 
   if(modHDRSEIs.hasST2094_10)
@@ -1530,3 +1598,31 @@ QPTableType ConvertOMXToMediaQpTable(OMX_ALG_EQpTableMode mode)
 
   return QPTableType::QP_TABLE_MAX_ENUM;
 }
+
+OMX_ALG_EStartCodeBytesAligment ConvertMediaToOMXStartCodeBytesAlignment(StartCodeBytesAlignmentType mode)
+{
+  switch(mode)
+  {
+  case StartCodeBytesAlignmentType::START_CODE_BYTES_ALIGNMENT_AUTO: return OMX_ALG_START_CODE_BYTES_ALIGNMENT_AUTO;
+  case StartCodeBytesAlignmentType::START_CODE_BYTES_ALIGNMENT_3_BYTES: return OMX_ALG_START_CODE_BYTES_ALIGNMENT_3_BYTES;
+  case StartCodeBytesAlignmentType::START_CODE_BYTES_ALIGNMENT_4_BYTES: return OMX_ALG_START_CODE_BYTES_ALIGNMENT_4_BYTES;
+  case StartCodeBytesAlignmentType::START_CODE_BYTES_ALIGNMENT_MAX_ENUM: return OMX_ALG_START_CODE_BYTES_ALIGNMENT_MAX_ENUM;
+  default: return OMX_ALG_START_CODE_BYTES_ALIGNMENT_MAX_ENUM;
+  }
+
+  return OMX_ALG_START_CODE_BYTES_ALIGNMENT_MAX_ENUM;
+}
+
+StartCodeBytesAlignmentType ConvertOMXToMediaStartCodeBytesAlignment(OMX_ALG_EStartCodeBytesAligment mode)
+{
+  switch(mode)
+  {
+  case OMX_ALG_START_CODE_BYTES_ALIGNMENT_AUTO: return StartCodeBytesAlignmentType::START_CODE_BYTES_ALIGNMENT_AUTO;
+  case OMX_ALG_START_CODE_BYTES_ALIGNMENT_3_BYTES: return StartCodeBytesAlignmentType::START_CODE_BYTES_ALIGNMENT_3_BYTES;
+  case OMX_ALG_START_CODE_BYTES_ALIGNMENT_4_BYTES: return StartCodeBytesAlignmentType::START_CODE_BYTES_ALIGNMENT_4_BYTES;
+  case OMX_ALG_START_CODE_BYTES_ALIGNMENT_MAX_ENUM: return StartCodeBytesAlignmentType::START_CODE_BYTES_ALIGNMENT_MAX_ENUM;
+  default: return StartCodeBytesAlignmentType::START_CODE_BYTES_ALIGNMENT_MAX_ENUM;
+  }
+
+  return StartCodeBytesAlignmentType::START_CODE_BYTES_ALIGNMENT_MAX_ENUM;
+}
