@@ -50,9 +50,12 @@ extern "C"
 #include <lib_common/BufferPixMapMeta.h>
 #include <lib_common/BufferStreamMeta.h>
 #include <lib_common/BufferHandleMeta.h>
+#include <lib_common/Error.h>
+
 #include <lib_common_dec/HDRMeta.h>
-#include <lib_fpga/DmaAllocLinux.h>
 #include <lib_common_dec/IpDecFourCC.h>
+
+#include <lib_fpga/DmaAllocLinux.h>
 }
 
 using namespace std;
@@ -81,28 +84,20 @@ void DecModule::ResetHDR()
   currentColorPrimaries = ColorPrimariesType::COLOR_PRIMARIES_UNSPECIFIED;
   currentHDRSEIs.hasMDCV = false;
   currentHDRSEIs.hasCLL = false;
+  currentHDRSEIs.hasST2094_10 = false;
+  currentHDRSEIs.hasST2094_40 = false;
 }
 
 DecModule::~DecModule() = default;
 
-static map<int, string> MapToStringDecodeError =
-{
-  { AL_ERR_NO_MEMORY, "decoder: memory allocation failure (firmware or ctrlsw)" },
-  { AL_ERR_CHAN_CREATION_NO_CHANNEL_AVAILABLE, "decoder: no channel available on the hardware" },
-  { AL_ERR_CHAN_CREATION_RESOURCE_UNAVAILABLE, "decoder: hardware doesn't have enough resources" },
-  { AL_ERR_CHAN_CREATION_NOT_ENOUGH_CORES, "decoder: hardware doesn't have enough resources (fragmentation)" },
-  { AL_ERR_REQUEST_MALFORMED, "decoder: request to hardware was malformed" },
-  { AL_WARN_CONCEAL_DETECT, "decoder: concealment" },
-  { AL_WARN_SPS_NOT_COMPATIBLE_WITH_CHANNEL_SETTINGS, "decoder: some SPS not compatible with the channel settings has been disacarded" },
-  { AL_WARN_SEI_OVERFLOW, "decoder: some SEI metadata buffer was too small" },
-};
-
-static string ToStringDecodeError(int error)
+static string ToStringDecodeError(AL_ERR error)
 {
   string str_error = "";
   try
   {
-    str_error = MapToStringDecodeError.at(error);
+    str_error = string {
+      AL_Codec_ErrorToString(error)
+    };
   }
   catch(out_of_range& e)
   {
@@ -363,6 +358,14 @@ ModuleInterface::ErrorType DecModule::CreateDecoder(bool shouldPrealloc)
   if(inputParsed)
     decCallbacks.parsedSeiCB = { nullptr, nullptr };
 
+  // Fix: remove this line and below block when a better fix is found
+  // This is a Gstreamer issue (not OMX) for allocation!
+  int tmp_height = media->settings.tStream.tDim.iHeight;
+  {
+    if(shouldPrealloc)
+      media->settings.tStream.tDim.iHeight = RoundUp(media->settings.tStream.tDim.iHeight, 16);
+  }
+
   auto errorCode = AL_Decoder_Create(&decoder, channel, allocator.get(), &media->settings, &decCallbacks);
 
   if(AL_IS_ERROR_CODE(errorCode))
@@ -379,6 +382,10 @@ ModuleInterface::ErrorType DecModule::CreateDecoder(bool shouldPrealloc)
       DestroyDecoder();
       return ToModuleError(errorCode);
     }
+
+    // Fix remove this line when a better fix is found
+    // This is a Gstreamer issue (not OMX) for allocation!
+    media->settings.tStream.tDim.iHeight = tmp_height;
   }
 
   return SUCCESS;
@@ -590,7 +597,20 @@ bool DecModule::CreateAndAttachStreamMeta(AL_TBuffer& buf)
   return true;
 }
 
-AL_ESectionFlags ConvertModuleToSoftFlags(Flags flags)
+AL_EStreamBufFlags ConvertModuleToSoftStreamBufFlag(Flags flags)
+{
+  AL_EStreamBufFlags streamBufFlag = AL_STREAM_BUF_FLAG_UNKNOWN;
+
+  if(flags.isEndOfSlice)
+    streamBufFlag = static_cast<AL_EStreamBufFlags>(streamBufFlag | AL_STREAM_BUF_FLAG_ENDOFSLICE);
+
+  if(flags.isEndOfFrame)
+    streamBufFlag = static_cast<AL_EStreamBufFlags>(streamBufFlag | AL_STREAM_BUF_FLAG_ENDOFFRAME);
+
+  return streamBufFlag;
+}
+
+AL_ESectionFlags ConvertModuleToSoftSectionFlags(Flags flags)
 {
   AL_ESectionFlags softFlags = AL_SECTION_NO_FLAG;
 
@@ -633,7 +653,7 @@ bool DecModule::Empty(BufferHandleInterface* handle)
     }
     auto streamMeta = (AL_TStreamMetaData*)(AL_Buffer_GetMetaData(input, AL_META_TYPE_STREAM));
     AL_StreamMetaData_ClearAllSections(streamMeta);
-    AL_StreamMetaData_AddSection(streamMeta, 0, handle->payload, ConvertModuleToSoftFlags(currentFlags));
+    AL_StreamMetaData_AddSection(streamMeta, 0, handle->payload, ConvertModuleToSoftSectionFlags(currentFlags));
 
     if(!AL_Buffer_GetMetaData(input, AL_META_TYPE_SEI))
     {
@@ -649,7 +669,7 @@ bool DecModule::Empty(BufferHandleInterface* handle)
 
   handles.Add(input, handle);
 
-  auto pushed = AL_Decoder_PushBuffer(decoder, input, handle->payload);
+  auto pushed = AL_Decoder_PushStreamBuffer(decoder, input, handle->payload, ConvertModuleToSoftStreamBufFlag(currentFlags));
 
   if(!inputParsed)
     AL_Buffer_Unref(input);
